summaryrefslogtreecommitdiff
path: root/sw/source/core/draw
diff options
context:
space:
mode:
authorRobinson Tryon <qubit@runcibility.com>2015-11-25 06:03:10 -0500
committerRobinson Tryon <qubit@runcibility.com>2015-11-25 06:07:38 -0500
commit49c2b9808df8a6b197dec666dfc0cda6321a4306 (patch)
tree045ef4b9b8dfdb06bfbe18cdf773d59f57d5552d /sw/source/core/draw
parent5470a365f25e5052b4dd74f76aa2196f0d70934b (diff)
bin/rename-sw-abbreviations.sh libreoffice-5-1-branch-point
This commit renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I77e5134f42f25e3786afa36b7a505c7e3237a9e8
Diffstat (limited to 'sw/source/core/draw')
-rw-r--r--sw/source/core/draw/dcontact.cxx292
-rw-r--r--sw/source/core/draw/dflyobj.cxx150
-rw-r--r--sw/source/core/draw/dpage.cxx18
-rw-r--r--sw/source/core/draw/dview.cxx126
4 files changed, 293 insertions, 293 deletions
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index c94781b33110..3ded66f433e5 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -73,7 +73,7 @@
using namespace ::com::sun::star;
-void setContextWritingMode( SdrObject* pObj, SwFrm* pAnchor )
+void setContextWritingMode( SdrObject* pObj, SwFrame* pAnchor )
{
if( pObj && pAnchor )
{
@@ -199,12 +199,12 @@ void SwContact::MoveObjToVisibleLayer( SdrObject* _pDrawObj )
"<SwContact::MoveObjToInvisibleLayer(..)> - missing anchored object" );
if ( pAnchoredObj )
{
- ::setContextWritingMode( _pDrawObj, pAnchoredObj->GetAnchorFrmContainingAnchPos() );
+ ::setContextWritingMode( _pDrawObj, pAnchoredObj->GetAnchorFrameContainingAnchPos() );
// Note: as-character anchored objects aren't registered at a page frame and
// a notification of its background isn't needed.
- if ( pAnchoredObj->GetPageFrm() )
+ if ( pAnchoredObj->GetPageFrame() )
{
- ::Notify_Background( _pDrawObj, pAnchoredObj->GetPageFrm(),
+ ::Notify_Background( _pDrawObj, pAnchoredObj->GetPageFrame(),
pAnchoredObj->GetObjRect(), PREP_FLY_ARRIVE, true );
}
@@ -229,9 +229,9 @@ void SwContact::MoveObjToInvisibleLayer( SdrObject* _pDrawObj )
"<SwContact::MoveObjToInvisibleLayer(..)> - missing anchored object" );
// Note: as-character anchored objects aren't registered at a page frame and
// a notification of its background isn't needed.
- if ( pAnchoredObj && pAnchoredObj->GetPageFrm() )
+ if ( pAnchoredObj && pAnchoredObj->GetPageFrame() )
{
- ::Notify_Background( _pDrawObj, pAnchoredObj->GetPageFrm(),
+ ::Notify_Background( _pDrawObj, pAnchoredObj->GetPageFrame(),
pAnchoredObj->GetObjRect(), PREP_FLY_LEAVE, true );
}
}
@@ -417,7 +417,7 @@ const SwAnchoredObject* SwFlyDrawContact::GetAnchoredObj( const SdrObject* _pSdr
if ( _pSdrObj && dynamic_cast<const SwVirtFlyDrawObj*>( _pSdrObj) != nullptr )
{
- pRetAnchoredObj = static_cast<const SwVirtFlyDrawObj*>(_pSdrObj)->GetFlyFrm();
+ pRetAnchoredObj = static_cast<const SwVirtFlyDrawObj*>(_pSdrObj)->GetFlyFrame();
}
return pRetAnchoredObj;
@@ -436,7 +436,7 @@ SwAnchoredObject* SwFlyDrawContact::GetAnchoredObj( SdrObject* _pSdrObj )
if ( _pSdrObj && dynamic_cast<const SwVirtFlyDrawObj*>( _pSdrObj) != nullptr )
{
- pRetAnchoredObj = static_cast<SwVirtFlyDrawObj*>(_pSdrObj)->GetFlyFrm();
+ pRetAnchoredObj = static_cast<SwVirtFlyDrawObj*>(_pSdrObj)->GetFlyFrame();
}
return pRetAnchoredObj;
@@ -479,22 +479,22 @@ void SwFlyDrawContact::MoveObjToVisibleLayer( SdrObject* _pDrawObj )
return;
}
- SwFlyFrm* pFlyFrm = static_cast<SwVirtFlyDrawObj*>(_pDrawObj)->GetFlyFrm();
+ SwFlyFrame* pFlyFrame = static_cast<SwVirtFlyDrawObj*>(_pDrawObj)->GetFlyFrame();
// #i44464# - consider, that Writer fly frame content
// already exists - (e.g. WW8 document is inserted into a existing document).
- if ( !pFlyFrm->Lower() )
+ if ( !pFlyFrame->Lower() )
{
- pFlyFrm->InsertColumns();
- pFlyFrm->Chain( pFlyFrm->AnchorFrm() );
- pFlyFrm->InsertCnt();
+ pFlyFrame->InsertColumns();
+ pFlyFrame->Chain( pFlyFrame->AnchorFrame() );
+ pFlyFrame->InsertCnt();
}
- if ( pFlyFrm->GetDrawObjs() )
+ if ( pFlyFrame->GetDrawObjs() )
{
- for ( size_t i = 0; i < pFlyFrm->GetDrawObjs()->size(); ++i)
+ for ( size_t i = 0; i < pFlyFrame->GetDrawObjs()->size(); ++i)
{
// #i28701# - consider type of objects in sorted object list.
- SdrObject* pObj = (*pFlyFrm->GetDrawObjs())[i]->DrawObj();
+ SdrObject* pObj = (*pFlyFrame->GetDrawObjs())[i]->DrawObj();
SwContact* pContact = static_cast<SwContact*>(pObj->GetUserCall());
pContact->MoveObjToVisibleLayer( pObj );
}
@@ -520,16 +520,16 @@ void SwFlyDrawContact::MoveObjToInvisibleLayer( SdrObject* _pDrawObj )
return;
}
- SwFlyFrm* pFlyFrm = static_cast<SwVirtFlyDrawObj*>(_pDrawObj)->GetFlyFrm();
+ SwFlyFrame* pFlyFrame = static_cast<SwVirtFlyDrawObj*>(_pDrawObj)->GetFlyFrame();
- pFlyFrm->Unchain();
- pFlyFrm->DeleteCnt();
- if ( pFlyFrm->GetDrawObjs() )
+ pFlyFrame->Unchain();
+ pFlyFrame->DeleteCnt();
+ if ( pFlyFrame->GetDrawObjs() )
{
- for ( size_t i = 0; i < pFlyFrm->GetDrawObjs()->size(); ++i)
+ for ( size_t i = 0; i < pFlyFrame->GetDrawObjs()->size(); ++i)
{
// #i28701# - consider type of objects in sorted object list.
- SdrObject* pObj = (*pFlyFrm->GetDrawObjs())[i]->DrawObj();
+ SdrObject* pObj = (*pFlyFrame->GetDrawObjs())[i]->DrawObj();
SwContact* pContact = static_cast<SwContact*>(pObj->GetUserCall());
pContact->MoveObjToInvisibleLayer( pObj );
}
@@ -543,7 +543,7 @@ void SwFlyDrawContact::MoveObjToInvisibleLayer( SdrObject* _pDrawObj )
void SwFlyDrawContact::GetAnchoredObjs( std::list<SwAnchoredObject*>& _roAnchoredObjs ) const
{
const SwFrameFormat* pFormat = GetFormat();
- SwFlyFrm::GetAnchoredObjects( _roAnchoredObjs, *pFormat );
+ SwFlyFrame::GetAnchoredObjects( _roAnchoredObjs, *pFormat );
}
// SwDrawContact
@@ -763,45 +763,45 @@ void SwDrawContact::SetMaster( SdrObject* _pNewMaster )
}
}
-const SwFrm* SwDrawContact::GetAnchorFrm( const SdrObject* _pDrawObj ) const
+const SwFrame* SwDrawContact::GetAnchorFrame( const SdrObject* _pDrawObj ) const
{
- const SwFrm* pAnchorFrm = nullptr;
+ const SwFrame* pAnchorFrame = nullptr;
if ( !_pDrawObj ||
_pDrawObj == GetMaster() ||
( !_pDrawObj->GetUserCall() &&
GetUserCall( _pDrawObj ) == static_cast<const SwContact* const>(this) ) )
{
- pAnchorFrm = maAnchoredDrawObj.GetAnchorFrm();
+ pAnchorFrame = maAnchoredDrawObj.GetAnchorFrame();
}
else if ( dynamic_cast<const SwDrawVirtObj*>( _pDrawObj) != nullptr )
{
- pAnchorFrm = static_cast<const SwDrawVirtObj*>(_pDrawObj)->GetAnchorFrm();
+ pAnchorFrame = static_cast<const SwDrawVirtObj*>(_pDrawObj)->GetAnchorFrame();
}
else
{
- OSL_FAIL( "<SwDrawContact::GetAnchorFrm(..)> - unknown drawing object." );
+ OSL_FAIL( "<SwDrawContact::GetAnchorFrame(..)> - unknown drawing object." );
}
- return pAnchorFrm;
+ return pAnchorFrame;
}
-SwFrm* SwDrawContact::GetAnchorFrm( SdrObject* _pDrawObj )
+SwFrame* SwDrawContact::GetAnchorFrame( SdrObject* _pDrawObj )
{
- SwFrm* pAnchorFrm = nullptr;
+ SwFrame* pAnchorFrame = nullptr;
if ( !_pDrawObj ||
_pDrawObj == GetMaster() ||
( !_pDrawObj->GetUserCall() &&
GetUserCall( _pDrawObj ) == this ) )
{
- pAnchorFrm = maAnchoredDrawObj.AnchorFrm();
+ pAnchorFrame = maAnchoredDrawObj.AnchorFrame();
}
else
{
OSL_ENSURE( dynamic_cast<const SwDrawVirtObj*>( _pDrawObj) != nullptr,
- "<SwDrawContact::GetAnchorFrm(..)> - unknown drawing object." );
- pAnchorFrm = static_cast<SwDrawVirtObj*>(_pDrawObj)->AnchorFrm();
+ "<SwDrawContact::GetAnchorFrame(..)> - unknown drawing object." );
+ pAnchorFrame = static_cast<SwDrawVirtObj*>(_pDrawObj)->AnchorFrame();
}
- return pAnchorFrm;
+ return pAnchorFrame;
}
/// create a new 'virtual' drawing object.
@@ -877,71 +877,71 @@ void SwDrawContact::RemoveAllVirtObjs()
maDrawVirtObjs.clear();
}
-SwDrawContact::VirtObjAnchoredAtFrmPred::VirtObjAnchoredAtFrmPred(
- const SwFrm& _rAnchorFrm )
- : mpAnchorFrm( &_rAnchorFrm )
+SwDrawContact::VirtObjAnchoredAtFramePred::VirtObjAnchoredAtFramePred(
+ const SwFrame& _rAnchorFrame )
+ : mpAnchorFrame( &_rAnchorFrame )
{
- if ( mpAnchorFrm->IsContentFrm() )
+ if ( mpAnchorFrame->IsContentFrame() )
{
- const SwContentFrm* pTmpFrm =
- static_cast<const SwContentFrm*>( mpAnchorFrm );
- while ( pTmpFrm->IsFollow() )
+ const SwContentFrame* pTmpFrame =
+ static_cast<const SwContentFrame*>( mpAnchorFrame );
+ while ( pTmpFrame->IsFollow() )
{
- pTmpFrm = pTmpFrm->FindMaster();
+ pTmpFrame = pTmpFrame->FindMaster();
}
- mpAnchorFrm = pTmpFrm;
+ mpAnchorFrame = pTmpFrame;
}
}
// #i26791# - compare with master frame
-bool SwDrawContact::VirtObjAnchoredAtFrmPred::operator() ( const SwDrawVirtObj* _pDrawVirtObj )
+bool SwDrawContact::VirtObjAnchoredAtFramePred::operator() ( const SwDrawVirtObj* _pDrawVirtObj )
{
- const SwFrm* pObjAnchorFrm = _pDrawVirtObj->GetAnchorFrm();
- if ( pObjAnchorFrm && pObjAnchorFrm->IsContentFrm() )
+ const SwFrame* pObjAnchorFrame = _pDrawVirtObj->GetAnchorFrame();
+ if ( pObjAnchorFrame && pObjAnchorFrame->IsContentFrame() )
{
- const SwContentFrm* pTmpFrm =
- static_cast<const SwContentFrm*>( pObjAnchorFrm );
- while ( pTmpFrm->IsFollow() )
+ const SwContentFrame* pTmpFrame =
+ static_cast<const SwContentFrame*>( pObjAnchorFrame );
+ while ( pTmpFrame->IsFollow() )
{
- pTmpFrm = pTmpFrm->FindMaster();
+ pTmpFrame = pTmpFrame->FindMaster();
}
- pObjAnchorFrm = pTmpFrm;
+ pObjAnchorFrame = pTmpFrame;
}
- return ( pObjAnchorFrm == mpAnchorFrm );
+ return ( pObjAnchorFrame == mpAnchorFrame );
}
/// get drawing object ('master' or 'virtual') by frame.
-SdrObject* SwDrawContact::GetDrawObjectByAnchorFrm( const SwFrm& _rAnchorFrm )
+SdrObject* SwDrawContact::GetDrawObjectByAnchorFrame( const SwFrame& _rAnchorFrame )
{
SdrObject* pRetDrawObj = nullptr;
// #i26791# - compare master frames instead of direct frames
- const SwFrm* pProposedAnchorFrm = &_rAnchorFrm;
- if ( pProposedAnchorFrm->IsContentFrm() )
+ const SwFrame* pProposedAnchorFrame = &_rAnchorFrame;
+ if ( pProposedAnchorFrame->IsContentFrame() )
{
- const SwContentFrm* pTmpFrm =
- static_cast<const SwContentFrm*>( pProposedAnchorFrm );
- while ( pTmpFrm->IsFollow() )
+ const SwContentFrame* pTmpFrame =
+ static_cast<const SwContentFrame*>( pProposedAnchorFrame );
+ while ( pTmpFrame->IsFollow() )
{
- pTmpFrm = pTmpFrm->FindMaster();
+ pTmpFrame = pTmpFrame->FindMaster();
}
- pProposedAnchorFrm = pTmpFrm;
+ pProposedAnchorFrame = pTmpFrame;
}
- const SwFrm* pMasterObjAnchorFrm = GetAnchorFrm();
- if ( pMasterObjAnchorFrm && pMasterObjAnchorFrm->IsContentFrm() )
+ const SwFrame* pMasterObjAnchorFrame = GetAnchorFrame();
+ if ( pMasterObjAnchorFrame && pMasterObjAnchorFrame->IsContentFrame() )
{
- const SwContentFrm* pTmpFrm =
- static_cast<const SwContentFrm*>( pMasterObjAnchorFrm );
- while ( pTmpFrm->IsFollow() )
+ const SwContentFrame* pTmpFrame =
+ static_cast<const SwContentFrame*>( pMasterObjAnchorFrame );
+ while ( pTmpFrame->IsFollow() )
{
- pTmpFrm = pTmpFrm->FindMaster();
+ pTmpFrame = pTmpFrame->FindMaster();
}
- pMasterObjAnchorFrm = pTmpFrm;
+ pMasterObjAnchorFrame = pTmpFrame;
}
- if ( pMasterObjAnchorFrm && pMasterObjAnchorFrm == pProposedAnchorFrm )
+ if ( pMasterObjAnchorFrame && pMasterObjAnchorFrame == pProposedAnchorFrame )
{
pRetDrawObj = GetMaster();
}
@@ -949,7 +949,7 @@ SdrObject* SwDrawContact::GetDrawObjectByAnchorFrm( const SwFrm& _rAnchorFrm )
{
std::list<SwDrawVirtObj*>::const_iterator aFoundVirtObjIter =
std::find_if( maDrawVirtObjs.begin(), maDrawVirtObjs.end(),
- VirtObjAnchoredAtFrmPred( *pProposedAnchorFrm ) );
+ VirtObjAnchoredAtFramePred( *pProposedAnchorFrame ) );
if ( aFoundVirtObjIter != maDrawVirtObjs.end() )
{
@@ -967,10 +967,10 @@ void SwDrawContact::NotifyBackgrdOfAllVirtObjs( const Rectangle* pOldBoundRect )
++aDrawVirtObjIter )
{
SwDrawVirtObj* pDrawVirtObj = (*aDrawVirtObjIter);
- if ( pDrawVirtObj->GetAnchorFrm() )
+ if ( pDrawVirtObj->GetAnchorFrame() )
{
// #i34640# - determine correct page frame
- SwPageFrm* pPage = pDrawVirtObj->AnchoredObj().FindPageFrmOfAnchor();
+ SwPageFrame* pPage = pDrawVirtObj->AnchoredObj().FindPageFrameOfAnchor();
if( pOldBoundRect && pPage )
{
SwRect aOldRect( *pOldBoundRect );
@@ -983,7 +983,7 @@ void SwDrawContact::NotifyBackgrdOfAllVirtObjs( const Rectangle* pOldBoundRect )
SwRect aRect( pDrawVirtObj->GetAnchoredObj().GetObjRectWithSpaces() );
if (aRect.HasArea() && pPage)
{
- SwPageFrm* pPg = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(::FindPage( aRect, pPage )));
+ SwPageFrame* pPg = const_cast<SwPageFrame*>(static_cast<const SwPageFrame*>(::FindPage( aRect, pPage )));
if ( pPg )
::Notify_Background( pDrawVirtObj, pPg, aRect,
PREP_FLY_ARRIVE, true );
@@ -1001,27 +1001,27 @@ static void lcl_NotifyBackgroundOfObj( SwDrawContact& _rDrawContact,
// #i34640#
SwAnchoredObject* pAnchoredObj =
const_cast<SwAnchoredObject*>(_rDrawContact.GetAnchoredObj( &_rObj ));
- if ( pAnchoredObj && pAnchoredObj->GetAnchorFrm() )
+ if ( pAnchoredObj && pAnchoredObj->GetAnchorFrame() )
{
// #i34640# - determine correct page frame
- SwPageFrm* pPageFrm = pAnchoredObj->FindPageFrmOfAnchor();
- if( _pOldObjRect && pPageFrm )
+ SwPageFrame* pPageFrame = pAnchoredObj->FindPageFrameOfAnchor();
+ if( _pOldObjRect && pPageFrame )
{
SwRect aOldRect( *_pOldObjRect );
if( aOldRect.HasArea() )
{
// #i34640# - determine correct page frame
- SwPageFrm* pOldPageFrm = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(::FindPage( aOldRect, pPageFrm )));
- ::Notify_Background( &_rObj, pOldPageFrm, aOldRect,
+ SwPageFrame* pOldPageFrame = const_cast<SwPageFrame*>(static_cast<const SwPageFrame*>(::FindPage( aOldRect, pPageFrame )));
+ ::Notify_Background( &_rObj, pOldPageFrame, aOldRect,
PREP_FLY_LEAVE, true);
}
}
// #i34640# - include spacing for wrapping
SwRect aNewRect( pAnchoredObj->GetObjRectWithSpaces() );
- if( aNewRect.HasArea() && pPageFrm )
+ if( aNewRect.HasArea() && pPageFrame )
{
- pPageFrm = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(::FindPage( aNewRect, pPageFrm )));
- ::Notify_Background( &_rObj, pPageFrm, aNewRect,
+ pPageFrame = const_cast<SwPageFrame*>(static_cast<const SwPageFrame*>(::FindPage( aNewRect, pPageFrame )));
+ ::Notify_Background( &_rObj, pPageFrame, aNewRect,
PREP_FLY_ARRIVE, true );
}
ClrContourCache( &_rObj );
@@ -1051,7 +1051,7 @@ void SwDrawContact::Changed( const SdrObject& rObj,
//Put on Action, but not if presently anywhere an action runs.
bool bHasActions(true);
- SwRootFrm *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
+ SwRootFrame *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
if ( pTmpRoot && pTmpRoot->IsCallbackActionEnabled() )
{
SwViewShell* const pSh = pDoc->getIDocumentLayoutAccess().GetCurrentViewShell();
@@ -1155,9 +1155,9 @@ void lcl_textBoxSizeNotify(SwFrameFormat* pFormat)
{
// Just notify the textbox that the size has changed, the actual object size is not interesting.
SfxItemSet aResizeSet(pFormat->GetDoc()->GetAttrPool(), RES_FRM_SIZE, RES_FRM_SIZE, 0);
- SwFormatFrmSize aSize;
+ SwFormatFrameSize aSize;
aResizeSet.Put(aSize);
- SwTextBoxHelper::syncFlyFrmAttr(*pFormat, aResizeSet);
+ SwTextBoxHelper::syncFlyFrameAttr(*pFormat, aResizeSet);
}
}
@@ -1371,7 +1371,7 @@ void SwDrawContact::_Changed( const SdrObject& rObj,
if ( nYPosDiff ||
( !bAnchoredAsChar && nXPosDiff != 0 ) )
{
- GetFormat()->GetDoc()->SetFlyFrmAttr( *(GetFormat()), aSet );
+ GetFormat()->GetDoc()->SetFlyFrameAttr( *(GetFormat()), aSet );
// keep new object rectangle, to avoid multiple
// changes of the attributes by multiple event from
// the drawing layer - e.g. group objects and its members
@@ -1387,10 +1387,10 @@ void SwDrawContact::_Changed( const SdrObject& rObj,
// of as-character anchored object
if ( bAnchoredAsChar )
{
- SwFrm* pAnchorFrm = const_cast<SwAnchoredDrawObject*>(pAnchoredDrawObj)->AnchorFrm();
- if(pAnchorFrm)
+ SwFrame* pAnchorFrame = const_cast<SwAnchoredDrawObject*>(pAnchoredDrawObj)->AnchorFrame();
+ if(pAnchorFrame)
{
- pAnchorFrm->Prepare( PREP_FLY_ATTR_CHG, GetFormat() );
+ pAnchorFrame->Prepare( PREP_FLY_ATTR_CHG, GetFormat() );
}
}
@@ -1455,7 +1455,7 @@ void SwDrawContact::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
// for notification
const Rectangle* pOldRect = nullptr;
Rectangle aOldRect;
- if ( GetAnchorFrm() )
+ if ( GetAnchorFrame() )
{
// --> #i36181# - include spacing in object
// rectangle for notification.
@@ -1485,7 +1485,7 @@ void SwDrawContact::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
DisconnectFromLayout();
}
// --> #i62875# - no further notification, if not connected to Writer layout
- else if ( maAnchoredDrawObj.GetAnchorFrm() &&
+ else if ( maAnchoredDrawObj.GetAnchorFrame() &&
maAnchoredDrawObj.GetDrawObj()->GetUserCall() )
{
// --> #i28701# - on change of wrapping style, hell|heaven layer,
@@ -1590,7 +1590,7 @@ void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
// --> #i36181# - notify background of drawing object
if ( _bMoveMasterToInvisibleLayer &&
!(GetFormat()->GetDoc()->IsInDtor()) &&
- GetAnchorFrm() && !GetAnchorFrm()->IsInDtor() )
+ GetAnchorFrame() && !GetAnchorFrame()->IsInDtor() )
{
const Rectangle aOldRect( maAnchoredDrawObj.GetObjRectWithSpaces().SVRect() );
lcl_NotifyBackgroundOfObj( *this, *GetMaster(), &aOldRect );
@@ -1608,9 +1608,9 @@ void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
pDrawVirtObj->RemoveFromDrawingPage();
}
- if ( maAnchoredDrawObj.GetAnchorFrm() )
+ if ( maAnchoredDrawObj.GetAnchorFrame() )
{
- maAnchoredDrawObj.AnchorFrm()->RemoveDrawObj( maAnchoredDrawObj );
+ maAnchoredDrawObj.AnchorFrame()->RemoveDrawObj( maAnchoredDrawObj );
}
if ( _bMoveMasterToInvisibleLayer && GetMaster() && GetMaster()->IsInserted() )
@@ -1674,15 +1674,15 @@ void SwDrawContact::DisconnectObjFromLayout( SdrObject* _pDrawObj )
// replace found 'virtual' drawing object by 'master' drawing
// object and disconnect the 'virtual' one
SwDrawVirtObj* pDrawVirtObj = (*aFoundVirtObjIter);
- SwFrm* pNewAnchorFrmOfMaster = pDrawVirtObj->AnchorFrm();
+ SwFrame* pNewAnchorFrameOfMaster = pDrawVirtObj->AnchorFrame();
// disconnect 'virtual' drawing object
pDrawVirtObj->RemoveFromWriterLayout();
pDrawVirtObj->RemoveFromDrawingPage();
// disconnect 'master' drawing object from current frame
- GetAnchorFrm()->RemoveDrawObj( maAnchoredDrawObj );
+ GetAnchorFrame()->RemoveDrawObj( maAnchoredDrawObj );
// re-connect 'master' drawing object to frame of found 'virtual'
// drawing object.
- pNewAnchorFrmOfMaster->AppendDrawObj( maAnchoredDrawObj );
+ pNewAnchorFrameOfMaster->AppendDrawObj( maAnchoredDrawObj );
}
else
{
@@ -1693,11 +1693,11 @@ void SwDrawContact::DisconnectObjFromLayout( SdrObject* _pDrawObj )
}
}
-static SwTextFrm* lcl_GetFlyInContentAnchor( SwTextFrm* _pProposedAnchorFrm,
+static SwTextFrame* lcl_GetFlyInContentAnchor( SwTextFrame* _pProposedAnchorFrame,
const sal_Int32 _nTextOfs )
{
- SwTextFrm* pAct = _pProposedAnchorFrm;
- SwTextFrm* pTmp;
+ SwTextFrame* pAct = _pProposedAnchorFrame;
+ SwTextFrame* pTmp;
do
{
pTmp = pAct;
@@ -1747,12 +1747,12 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
SwViewShell *pShell = pDrawFrameFormat->getIDocumentLayoutAccess().GetCurrentViewShell();
if( !pShell )
break;
- SwRootFrm* pRoot = pShell->GetLayout();
- SwPageFrm *pPage = static_cast<SwPageFrm*>(pRoot->Lower());
+ SwRootFrame* pRoot = pShell->GetLayout();
+ SwPageFrame *pPage = static_cast<SwPageFrame*>(pRoot->Lower());
for ( sal_uInt16 i = 1; i < nPgNum && pPage; ++i )
{
- pPage = static_cast<SwPageFrm*>(pPage->GetNext());
+ pPage = static_cast<SwPageFrame*>(pPage->GetNext());
}
if ( pPage )
@@ -1778,7 +1778,7 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
// but not control objects:
// anchor at first found frame the 'master' object and
// at the following frames 'virtual' drawing objects.
- // Note: method is similar to <SwFlyFrameFormat::MakeFrms(..)>
+ // Note: method is similar to <SwFlyFrameFormat::MakeFrames(..)>
SwModify *pModify = nullptr;
if( pAnch->GetContentAnchor() )
{
@@ -1786,7 +1786,7 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
{
SwNodeIndex aIdx( pAnch->GetContentAnchor()->nNode );
SwContentNode* pCNd = pDrawFrameFormat->GetDoc()->GetNodes().GoNext( &aIdx );
- if ( SwIterator<SwFrm,SwContentNode>( *pCNd ).First() )
+ if ( SwIterator<SwFrame,SwContentNode>( *pCNd ).First() )
pModify = pCNd;
else
{
@@ -1819,42 +1819,42 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
break;
}
- SwIterator<SwFrm,SwModify> aIter( *pModify );
- SwFrm* pAnchorFrmOfMaster = nullptr;
- for( SwFrm *pFrm = aIter.First(); pFrm; pFrm = aIter.Next() )
+ SwIterator<SwFrame,SwModify> aIter( *pModify );
+ SwFrame* pAnchorFrameOfMaster = nullptr;
+ for( SwFrame *pFrame = aIter.First(); pFrame; pFrame = aIter.Next() )
{
// append drawing object, if
// (1) proposed anchor frame isn't a follow and
// (2) drawing object isn't a control object to be anchored
// in header/footer.
- const bool bAdd = ( !pFrm->IsContentFrm() ||
- !static_cast<SwContentFrm*>(pFrm)->IsFollow() ) &&
+ const bool bAdd = ( !pFrame->IsContentFrame() ||
+ !static_cast<SwContentFrame*>(pFrame)->IsFollow() ) &&
( !::CheckControlLayer( GetMaster() ) ||
- !pFrm->FindFooterOrHeader() );
+ !pFrame->FindFooterOrHeader() );
if( bAdd )
{
- if ( FLY_AT_FLY == pAnch->GetAnchorId() && !pFrm->IsFlyFrm() )
+ if ( FLY_AT_FLY == pAnch->GetAnchorId() && !pFrame->IsFlyFrame() )
{
- pFrm = pFrm->FindFlyFrm();
- OSL_ENSURE( pFrm,
+ pFrame = pFrame->FindFlyFrame();
+ OSL_ENSURE( pFrame,
"<SwDrawContact::ConnectToLayout(..)> - missing fly frame -> crash." );
}
// find correct follow for as character anchored objects
if ((pAnch->GetAnchorId() == FLY_AS_CHAR) &&
- pFrm->IsTextFrm() )
+ pFrame->IsTextFrame() )
{
- pFrm = lcl_GetFlyInContentAnchor(
- static_cast<SwTextFrm*>(pFrm),
+ pFrame = lcl_GetFlyInContentAnchor(
+ static_cast<SwTextFrame*>(pFrame),
pAnch->GetContentAnchor()->nContent.GetIndex() );
}
- if ( !pAnchorFrmOfMaster )
+ if ( !pAnchorFrameOfMaster )
{
// append 'master' drawing object
- pAnchorFrmOfMaster = pFrm;
- pFrm->AppendDrawObj( maAnchoredDrawObj );
+ pAnchorFrameOfMaster = pFrame;
+ pFrame->AppendDrawObj( maAnchoredDrawObj );
}
else
{
@@ -1864,14 +1864,14 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
{
ClrContourCache( pDrawVirtObj );
}
- pFrm->AppendDrawObj( pDrawVirtObj->AnchoredObj() );
+ pFrame->AppendDrawObj( pDrawVirtObj->AnchoredObj() );
pDrawVirtObj->ActionChanged();
}
if ( pAnch->GetAnchorId() == FLY_AS_CHAR )
{
- pFrm->InvalidatePrt();
+ pFrame->InvalidatePrt();
}
}
}
@@ -1881,9 +1881,9 @@ void SwDrawContact::ConnectToLayout( const SwFormatAnchor* pAnch )
OSL_FAIL( "Unknown Anchor." );
break;
}
- if ( GetAnchorFrm() )
+ if ( GetAnchorFrame() )
{
- ::setContextWritingMode( maAnchoredDrawObj.DrawObj(), GetAnchorFrm() );
+ ::setContextWritingMode( maAnchoredDrawObj.DrawObj(), GetAnchorFrame() );
// #i26791# - invalidate objects instead of direct positioning
_InvalidateObjs();
}
@@ -1900,14 +1900,14 @@ void SwDrawContact::InsertMasterIntoDrawPage()
GetMaster()->SetUserCall( this );
}
-SwPageFrm* SwDrawContact::FindPage( const SwRect &rRect )
+SwPageFrame* SwDrawContact::FindPage( const SwRect &rRect )
{
- // --> #i28701# - use method <GetPageFrm()>
- SwPageFrm* pPg = GetPageFrm();
- if ( !pPg && GetAnchorFrm() )
- pPg = GetAnchorFrm()->FindPageFrm();
+ // --> #i28701# - use method <GetPageFrame()>
+ SwPageFrame* pPg = GetPageFrame();
+ if ( !pPg && GetAnchorFrame() )
+ pPg = GetAnchorFrame()->FindPageFrame();
if ( pPg )
- pPg = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(::FindPage( rRect, pPg )));
+ pPg = const_cast<SwPageFrame*>(static_cast<const SwPageFrame*>(::FindPage( rRect, pPg )));
return pPg;
}
@@ -1920,26 +1920,26 @@ void SwDrawContact::ChkPage()
}
// --> #i28701#
- SwPageFrm* pPg = ( maAnchoredDrawObj.GetAnchorFrm() &&
- maAnchoredDrawObj.GetAnchorFrm()->IsPageFrm() )
- ? GetPageFrm()
+ SwPageFrame* pPg = ( maAnchoredDrawObj.GetAnchorFrame() &&
+ maAnchoredDrawObj.GetAnchorFrame()->IsPageFrame() )
+ ? GetPageFrame()
: FindPage( GetMaster()->GetCurrentBoundRect() );
- if ( GetPageFrm() != pPg )
+ if ( GetPageFrame() != pPg )
{
// if drawing object is anchor in header/footer a change of the page
// is a dramatic change. Thus, completely re-connect to the layout
- if ( maAnchoredDrawObj.GetAnchorFrm() &&
- maAnchoredDrawObj.GetAnchorFrm()->FindFooterOrHeader() )
+ if ( maAnchoredDrawObj.GetAnchorFrame() &&
+ maAnchoredDrawObj.GetAnchorFrame()->FindFooterOrHeader() )
{
ConnectToLayout();
}
else
{
- // --> #i28701# - use methods <GetPageFrm()> and <SetPageFrm>
- if ( GetPageFrm() )
- GetPageFrm()->RemoveDrawObjFromPage( maAnchoredDrawObj );
+ // --> #i28701# - use methods <GetPageFrame()> and <SetPageFrame>
+ if ( GetPageFrame() )
+ GetPageFrame()->RemoveDrawObjFromPage( maAnchoredDrawObj );
pPg->AppendDrawObjToPage( maAnchoredDrawObj );
- SetPageFrm( pPg );
+ SetPageFrame( pPg );
}
}
}
@@ -2185,25 +2185,25 @@ SwDrawVirtObj* SwDrawVirtObj::Clone() const
return pObj;
}
-const SwFrm* SwDrawVirtObj::GetAnchorFrm() const
+const SwFrame* SwDrawVirtObj::GetAnchorFrame() const
{
// #i26791# - use new member <maAnchoredDrawObj>
- return maAnchoredDrawObj.GetAnchorFrm();
+ return maAnchoredDrawObj.GetAnchorFrame();
}
-SwFrm* SwDrawVirtObj::AnchorFrm()
+SwFrame* SwDrawVirtObj::AnchorFrame()
{
// #i26791# - use new member <maAnchoredDrawObj>
- return maAnchoredDrawObj.AnchorFrm();
+ return maAnchoredDrawObj.AnchorFrame();
}
void SwDrawVirtObj::RemoveFromWriterLayout()
{
// remove contact object from frame for 'virtual' drawing object
// #i26791# - use new member <maAnchoredDrawObj>
- if ( maAnchoredDrawObj.GetAnchorFrm() )
+ if ( maAnchoredDrawObj.GetAnchorFrame() )
{
- maAnchoredDrawObj.AnchorFrm()->RemoveDrawObj( maAnchoredDrawObj );
+ maAnchoredDrawObj.AnchorFrame()->RemoveDrawObj( maAnchoredDrawObj );
}
}
@@ -2248,7 +2248,7 @@ void SwDrawVirtObj::RemoveFromDrawingPage()
/// Is 'virtual' drawing object connected to writer layout and to drawing layer?
bool SwDrawVirtObj::IsConnected() const
{
- bool bRetVal = GetAnchorFrm() &&
+ bool bRetVal = GetAnchorFrame() &&
( GetPage() && GetUserCall() );
return bRetVal;
diff --git a/sw/source/core/draw/dflyobj.cxx b/sw/source/core/draw/dflyobj.cxx
index d03ca0121f32..90262203ad3a 100644
--- a/sw/source/core/draw/dflyobj.cxx
+++ b/sw/source/core/draw/dflyobj.cxx
@@ -324,11 +324,11 @@ basegfx::B2DRange SwVirtFlyDrawObj::getOuterBound() const
if(dynamic_cast<const SwFlyDrawObj*>( &rReferencedObject) != nullptr)
{
- const SwFlyFrm* pFlyFrame = GetFlyFrm();
+ const SwFlyFrame* pFlyFrame = GetFlyFrame();
if(pFlyFrame)
{
- const Rectangle aOuterRectangle(pFlyFrame->Frm().Pos(), pFlyFrame->Frm().SSize());
+ const Rectangle aOuterRectangle(pFlyFrame->Frame().Pos(), pFlyFrame->Frame().SSize());
if(!aOuterRectangle.IsEmpty())
{
@@ -348,11 +348,11 @@ basegfx::B2DRange SwVirtFlyDrawObj::getInnerBound() const
if(dynamic_cast<const SwFlyDrawObj*>( &rReferencedObject) != nullptr)
{
- const SwFlyFrm* pFlyFrame = GetFlyFrm();
+ const SwFlyFrame* pFlyFrame = GetFlyFrame();
if(pFlyFrame)
{
- const Rectangle aInnerRectangle(pFlyFrame->Frm().Pos() + pFlyFrame->Prt().Pos(), pFlyFrame->Prt().SSize());
+ const Rectangle aInnerRectangle(pFlyFrame->Frame().Pos() + pFlyFrame->Prt().Pos(), pFlyFrame->Prt().SSize());
if(!aInnerRectangle.IsEmpty())
{
@@ -372,11 +372,11 @@ sdr::contact::ViewContact* SwVirtFlyDrawObj::CreateObjectSpecificViewContact()
return new sdr::contact::VCOfSwVirtFlyDrawObj(*this);
}
-SwVirtFlyDrawObj::SwVirtFlyDrawObj(SdrObject& rNew, SwFlyFrm* pFly) :
+SwVirtFlyDrawObj::SwVirtFlyDrawObj(SdrObject& rNew, SwFlyFrame* pFly) :
SdrVirtObj( rNew ),
- m_pFlyFrm( pFly )
+ m_pFlyFrame( pFly )
{
- const SvxProtectItem &rP = m_pFlyFrm->GetFormat()->GetProtect();
+ const SvxProtectItem &rP = m_pFlyFrame->GetFormat()->GetProtect();
bMovProt = rP.IsPosProtected();
bSizProt = rP.IsSizeProtected();
}
@@ -389,11 +389,11 @@ SwVirtFlyDrawObj::~SwVirtFlyDrawObj()
const SwFrameFormat *SwVirtFlyDrawObj::GetFormat() const
{
- return GetFlyFrm()->GetFormat();
+ return GetFlyFrame()->GetFormat();
}
SwFrameFormat *SwVirtFlyDrawObj::GetFormat()
{
- return GetFlyFrm()->GetFormat();
+ return GetFlyFrame()->GetFormat();
}
// --> OD #i102707#
@@ -444,7 +444,7 @@ namespace
void SwVirtFlyDrawObj::wrap_DoPaintObject(
drawinglayer::geometry::ViewInformation2D const& rViewInformation) const
{
- SwViewShell* pShell = m_pFlyFrm->getRootFrm()->GetCurrShell();
+ SwViewShell* pShell = m_pFlyFrame->getRootFrame()->GetCurrShell();
// Only paint when we have a current shell and a DrawingLayer paint is in progress.
// This avoids evtl. problems with renderers which do processing stuff,
@@ -455,7 +455,7 @@ void SwVirtFlyDrawObj::wrap_DoPaintObject(
{
bool bDrawObject(true);
- if ( !SwFlyFrm::IsPaint( const_cast<SwVirtFlyDrawObj*>(this), pShell ) )
+ if ( !SwFlyFrame::IsPaint( const_cast<SwVirtFlyDrawObj*>(this), pShell ) )
{
bDrawObject = false;
}
@@ -466,7 +466,7 @@ void SwVirtFlyDrawObj::wrap_DoPaintObject(
// which is slow, wastes memory, and can cause other trouble.
(void) rViewInformation; // suppress "unused parameter" warning
assert(comphelper::LibreOfficeKit::isActive() || !rViewInformation.getViewport().isEmpty());
- if ( !m_pFlyFrm->IsFlyInCntFrm() )
+ if ( !m_pFlyFrame->IsFlyInContentFrame() )
{
// it is also necessary to restore the VCL MapMode from ViewInformation since e.g.
// the VCL PixelRenderer resets it at the used OutputDevice. Unfortunately, this
@@ -477,7 +477,7 @@ void SwVirtFlyDrawObj::wrap_DoPaintObject(
RestoreMapMode aRestoreMapModeIfNeeded( pShell );
// paint the FlyFrame (use standard VCL-Paint)
- m_pFlyFrm->Paint( *pShell->GetOut(), GetFlyFrm()->Frm() );
+ m_pFlyFrame->Paint( *pShell->GetOut(), GetFlyFrame()->Frame() );
}
}
}
@@ -499,8 +499,8 @@ void SwVirtFlyDrawObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
void SwVirtFlyDrawObj::SetRect() const
{
- if ( GetFlyFrm()->Frm().HasArea() )
- const_cast<SwVirtFlyDrawObj*>(this)->aOutRect = GetFlyFrm()->Frm().SVRect();
+ if ( GetFlyFrame()->Frame().HasArea() )
+ const_cast<SwVirtFlyDrawObj*>(this)->aOutRect = GetFlyFrame()->Frame().SVRect();
else
const_cast<SwVirtFlyDrawObj*>(this)->aOutRect = Rectangle();
}
@@ -570,7 +570,7 @@ void SwVirtFlyDrawObj::NbcSetLogicRect(const Rectangle& )
::basegfx::B2DPolyPolygon SwVirtFlyDrawObj::TakeXorPoly() const
{
- const Rectangle aSourceRectangle(GetFlyFrm()->Frm().SVRect());
+ const Rectangle aSourceRectangle(GetFlyFrame()->Frame().SVRect());
const ::basegfx::B2DRange aSourceRange(aSourceRectangle.Left(), aSourceRectangle.Top(), aSourceRectangle.Right(), aSourceRectangle.Bottom());
::basegfx::B2DPolyPolygon aRetval;
@@ -584,13 +584,13 @@ void SwVirtFlyDrawObj::NbcSetLogicRect(const Rectangle& )
void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
{
MoveRect( aOutRect, rSiz );
- const Point aOldPos( GetFlyFrm()->Frm().Pos() );
+ const Point aOldPos( GetFlyFrame()->Frame().Pos() );
const Point aNewPos( aOutRect.TopLeft() );
const SwRect aFlyRect( aOutRect );
//If the Fly has a automatic align (right or top),
//so preserve the automatic.
- SwFrameFormat *pFormat = GetFlyFrm()->GetFormat();
+ SwFrameFormat *pFormat = GetFlyFrame()->GetFormat();
const sal_Int16 eHori = pFormat->GetHoriOrient().GetHoriOrient();
const sal_Int16 eVert = pFormat->GetVertOrient().GetVertOrient();
const sal_Int16 eRelHori = pFormat->GetHoriOrient().GetRelationOrient();
@@ -598,8 +598,8 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
//On paragraph bound Flys starting from the new position a new
//anchor must be set. Anchor and the new RelPos is calculated and
//placed by the Fly itself.
- if( GetFlyFrm()->IsFlyAtCntFrm() )
- static_cast<SwFlyAtCntFrm*>(GetFlyFrm())->SetAbsPos( aNewPos );
+ if( GetFlyFrame()->IsFlyAtContentFrame() )
+ static_cast<SwFlyAtContentFrame*>(GetFlyFrame())->SetAbsPos( aNewPos );
else
{
const SwFrameFormat *pTmpFormat = GetFormat();
@@ -607,20 +607,20 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
const SwFormatHoriOrient &rHori = pTmpFormat->GetHoriOrient();
long lXDiff = aNewPos.X() - aOldPos.X();
if( rHori.IsPosToggle() && text::HoriOrientation::NONE == eHori &&
- !GetFlyFrm()->FindPageFrm()->OnRightPage() )
+ !GetFlyFrame()->FindPageFrame()->OnRightPage() )
lXDiff = -lXDiff;
- if( GetFlyFrm()->GetAnchorFrm()->IsRightToLeft() &&
+ if( GetFlyFrame()->GetAnchorFrame()->IsRightToLeft() &&
text::HoriOrientation::NONE == eHori )
lXDiff = -lXDiff;
long lYDiff = aNewPos.Y() - aOldPos.Y();
- if( GetFlyFrm()->GetAnchorFrm()->IsVertical() )
+ if( GetFlyFrame()->GetAnchorFrame()->IsVertical() )
{
//lXDiff -= rVert.GetPos();
//lYDiff += rHori.GetPos();
- if ( GetFlyFrm()->GetAnchorFrm()->IsVertLR() )
+ if ( GetFlyFrame()->GetAnchorFrame()->IsVertLR() )
{
lXDiff += rVert.GetPos();
lXDiff = -lXDiff;
@@ -637,13 +637,13 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
lYDiff += rVert.GetPos();
}
- if( GetFlyFrm()->GetAnchorFrm()->IsRightToLeft() &&
+ if( GetFlyFrame()->GetAnchorFrame()->IsRightToLeft() &&
text::HoriOrientation::NONE != eHori )
- lXDiff = GetFlyFrm()->GetAnchorFrm()->Frm().Width() -
+ lXDiff = GetFlyFrame()->GetAnchorFrame()->Frame().Width() -
aFlyRect.Width() - lXDiff;
const Point aTmp( lXDiff, lYDiff );
- GetFlyFrm()->ChgRelPos( aTmp );
+ GetFlyFrame()->ChgRelPos( aTmp );
}
SwAttrSet aSet( pFormat->GetDoc()->GetAttrPool(),
@@ -652,15 +652,15 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
SwFormatVertOrient aVert( pFormat->GetVertOrient() );
bool bPut = false;
- if( !GetFlyFrm()->IsFlyLayFrm() &&
+ if( !GetFlyFrame()->IsFlyLayFrame() &&
::GetHtmlMode(pFormat->GetDoc()->GetDocShell()) )
{
//In HTML-Mode only automatic aligns are allowed.
//Only we can try a snap to left/right respectively left-/right border
- const SwFrm* pAnch = GetFlyFrm()->GetAnchorFrm();
+ const SwFrame* pAnch = GetFlyFrame()->GetAnchorFrame();
bool bNextLine = false;
- if( !GetFlyFrm()->IsAutoPos() || text::RelOrientation::PAGE_FRAME != aHori.GetRelationOrient() )
+ if( !GetFlyFrame()->IsAutoPos() || text::RelOrientation::PAGE_FRAME != aHori.GetRelationOrient() )
{
if( text::RelOrientation::CHAR == eRelHori )
{
@@ -671,21 +671,21 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
{
bNextLine = true;
//Horizontal Align:
- const bool bLeftFrm =
- aFlyRect.Left() < pAnch->Frm().Left() + pAnch->Prt().Left(),
+ const bool bLeftFrame =
+ aFlyRect.Left() < pAnch->Frame().Left() + pAnch->Prt().Left(),
bLeftPrt = aFlyRect.Left() + aFlyRect.Width() <
- pAnch->Frm().Left() + pAnch->Prt().Width()/2;
- if ( bLeftFrm || bLeftPrt )
+ pAnch->Frame().Left() + pAnch->Prt().Width()/2;
+ if ( bLeftFrame || bLeftPrt )
{
aHori.SetHoriOrient( text::HoriOrientation::LEFT );
- aHori.SetRelationOrient( bLeftFrm ? text::RelOrientation::FRAME : text::RelOrientation::PRINT_AREA );
+ aHori.SetRelationOrient( bLeftFrame ? text::RelOrientation::FRAME : text::RelOrientation::PRINT_AREA );
}
else
{
- const bool bRightFrm = aFlyRect.Left() >
- pAnch->Frm().Left() + pAnch->Prt().Width();
+ const bool bRightFrame = aFlyRect.Left() >
+ pAnch->Frame().Left() + pAnch->Prt().Width();
aHori.SetHoriOrient( text::HoriOrientation::RIGHT );
- aHori.SetRelationOrient( bRightFrm ? text::RelOrientation::FRAME : text::RelOrientation::PRINT_AREA );
+ aHori.SetRelationOrient( bRightFrame ? text::RelOrientation::FRAME : text::RelOrientation::PRINT_AREA );
}
}
aSet.Put( aHori );
@@ -694,7 +694,7 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
//only on manual align will be switched over.
bool bRelChar = text::RelOrientation::CHAR == eRelVert;
aVert.SetVertOrient( eVert != text::VertOrientation::NONE ? eVert :
- GetFlyFrm()->IsFlyInCntFrm() ? text::VertOrientation::CHAR_CENTER :
+ GetFlyFrame()->IsFlyInContentFrame() ? text::VertOrientation::CHAR_CENTER :
bRelChar && bNextLine ? text::VertOrientation::CHAR_TOP : text::VertOrientation::TOP );
if( bRelChar )
aVert.SetRelationOrient( text::RelOrientation::CHAR );
@@ -730,7 +730,7 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
void SwVirtFlyDrawObj::NbcCrop(const Point& rRef, const Fraction& xFact, const Fraction& yFact)
{
// Get Wrt Shell
- SwWrtShell *pSh = dynamic_cast<SwWrtShell*>( GetFlyFrm()->getRootFrm()->GetCurrShell() );
+ SwWrtShell *pSh = dynamic_cast<SwWrtShell*>( GetFlyFrame()->getRootFrame()->GetCurrShell() );
if (!pSh || dynamic_cast<const SwWrtShell*>( pSh) == nullptr)
return;
@@ -799,7 +799,7 @@ void SwVirtFlyDrawObj::NbcCrop(const Point& rRef, const Fraction& xFact, const F
// Set new frame size
SwFrameFormat *pFormat = GetFormat();
- SwFormatFrmSize aSz( pFormat->GetFrmSize() );
+ SwFormatFrameSize aSz( pFormat->GetFrameSize() );
aSz.SetWidth(aNewRect.GetWidth());
aSz.SetHeight(aNewRect.GetHeight());
pFormat->GetDoc()->SetAttr( aSz, *pFormat );
@@ -814,14 +814,14 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef,
{
ResizeRect( aOutRect, rRef, xFact, yFact );
- const SwFrm* pTmpFrm = GetFlyFrm()->GetAnchorFrm();
- if( !pTmpFrm )
- pTmpFrm = GetFlyFrm();
- const bool bVertX = pTmpFrm->IsVertical();
+ const SwFrame* pTmpFrame = GetFlyFrame()->GetAnchorFrame();
+ if( !pTmpFrame )
+ pTmpFrame = GetFlyFrame();
+ const bool bVertX = pTmpFrame->IsVertical();
- const bool bRTL = pTmpFrm->IsRightToLeft();
+ const bool bRTL = pTmpFrame->IsRightToLeft();
- const bool bVertL2RX = pTmpFrm->IsVertLR();
+ const bool bVertL2RX = pTmpFrame->IsVertLR();
const Point aNewPos( ( bVertX && !bVertL2RX ) || bRTL ?
aOutRect.Right() + 1 :
aOutRect.Left(),
@@ -829,12 +829,12 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef,
Size aSz( aOutRect.Right() - aOutRect.Left() + 1,
aOutRect.Bottom()- aOutRect.Top() + 1 );
- if( aSz != GetFlyFrm()->Frm().SSize() )
+ if( aSz != GetFlyFrame()->Frame().SSize() )
{
//The width of the columns should not be too narrow
- if ( GetFlyFrm()->Lower() && GetFlyFrm()->Lower()->IsColumnFrm() )
+ if ( GetFlyFrame()->Lower() && GetFlyFrame()->Lower()->IsColumnFrame() )
{
- SwBorderAttrAccess aAccess( SwFrm::GetCache(), GetFlyFrm() );
+ SwBorderAttrAccess aAccess( SwFrame::GetCache(), GetFlyFrame() );
const SwBorderAttrs &rAttrs = *aAccess.Get();
long nMin = rAttrs.CalcLeftLine()+rAttrs.CalcRightLine();
const SwFormatCol& rCol = rAttrs.GetAttrSet().GetCol();
@@ -850,17 +850,17 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef,
}
SwFrameFormat *pFormat = GetFormat();
- const SwFormatFrmSize aOldFrmSz( pFormat->GetFrmSize() );
- GetFlyFrm()->ChgSize( aSz );
- SwFormatFrmSize aFrmSz( pFormat->GetFrmSize() );
- if ( aFrmSz.GetWidthPercent() || aFrmSz.GetHeightPercent() )
+ const SwFormatFrameSize aOldFrameSz( pFormat->GetFrameSize() );
+ GetFlyFrame()->ChgSize( aSz );
+ SwFormatFrameSize aFrameSz( pFormat->GetFrameSize() );
+ if ( aFrameSz.GetWidthPercent() || aFrameSz.GetHeightPercent() )
{
long nRelWidth, nRelHeight;
- const SwFrm *pRel = GetFlyFrm()->IsFlyLayFrm() ?
- GetFlyFrm()->GetAnchorFrm() :
- GetFlyFrm()->GetAnchorFrm()->GetUpper();
- const SwViewShell *pSh = GetFlyFrm()->getRootFrm()->GetCurrShell();
- if ( pSh && pRel->IsBodyFrm() &&
+ const SwFrame *pRel = GetFlyFrame()->IsFlyLayFrame() ?
+ GetFlyFrame()->GetAnchorFrame() :
+ GetFlyFrame()->GetAnchorFrame()->GetUpper();
+ const SwViewShell *pSh = GetFlyFrame()->getRootFrame()->GetCurrShell();
+ if ( pSh && pRel->IsBodyFrame() &&
pSh->GetViewOptions()->getBrowseMode() &&
pSh->VisArea().HasArea() )
{
@@ -874,20 +874,20 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef,
nRelWidth = pRel->Prt().Width();
nRelHeight = pRel->Prt().Height();
}
- if ( aFrmSz.GetWidthPercent() && aFrmSz.GetWidthPercent() != SwFormatFrmSize::SYNCED &&
- aOldFrmSz.GetWidth() != aFrmSz.GetWidth() )
- aFrmSz.SetWidthPercent( sal_uInt8(aSz.Width() * 100.0 / nRelWidth + 0.5) );
- if ( aFrmSz.GetHeightPercent() && aFrmSz.GetHeightPercent() != SwFormatFrmSize::SYNCED &&
- aOldFrmSz.GetHeight() != aFrmSz.GetHeight() )
- aFrmSz.SetHeightPercent( sal_uInt8(aSz.Height() * 100.0 / nRelHeight + 0.5) );
- pFormat->GetDoc()->SetAttr( aFrmSz, *pFormat );
+ if ( aFrameSz.GetWidthPercent() && aFrameSz.GetWidthPercent() != SwFormatFrameSize::SYNCED &&
+ aOldFrameSz.GetWidth() != aFrameSz.GetWidth() )
+ aFrameSz.SetWidthPercent( sal_uInt8(aSz.Width() * 100.0 / nRelWidth + 0.5) );
+ if ( aFrameSz.GetHeightPercent() && aFrameSz.GetHeightPercent() != SwFormatFrameSize::SYNCED &&
+ aOldFrameSz.GetHeight() != aFrameSz.GetHeight() )
+ aFrameSz.SetHeightPercent( sal_uInt8(aSz.Height() * 100.0 / nRelHeight + 0.5) );
+ pFormat->GetDoc()->SetAttr( aFrameSz, *pFormat );
}
}
//Position can also be changed!
const Point aOldPos( ( bVertX && !bVertL2RX ) || bRTL ?
- GetFlyFrm()->Frm().TopRight() :
- GetFlyFrm()->Frm().Pos() );
+ GetFlyFrame()->Frame().TopRight() :
+ GetFlyFrame()->Frame().Pos() );
if ( aNewPos != aOldPos )
{
//May have been altered by the ChgSize!
@@ -961,23 +961,23 @@ Pointer SwVirtFlyDrawObj::GetMacroPointer(
bool SwVirtFlyDrawObj::HasMacro() const
{
- const SwFormatURL &rURL = m_pFlyFrm->GetFormat()->GetURL();
+ const SwFormatURL &rURL = m_pFlyFrame->GetFormat()->GetURL();
return rURL.GetMap() || !rURL.GetURL().isEmpty();
}
SdrObject* SwVirtFlyDrawObj::CheckMacroHit( const SdrObjMacroHitRec& rRec ) const
{
- const SwFormatURL &rURL = m_pFlyFrm->GetFormat()->GetURL();
+ const SwFormatURL &rURL = m_pFlyFrame->GetFormat()->GetURL();
if( rURL.GetMap() || !rURL.GetURL().isEmpty() )
{
SwRect aRect;
- if ( m_pFlyFrm->Lower() && m_pFlyFrm->Lower()->IsNoTextFrm() )
+ if ( m_pFlyFrame->Lower() && m_pFlyFrame->Lower()->IsNoTextFrame() )
{
- aRect = m_pFlyFrm->Prt();
- aRect += m_pFlyFrm->Frm().Pos();
+ aRect = m_pFlyFrame->Prt();
+ aRect += m_pFlyFrame->Frame().Pos();
}
else
- aRect = m_pFlyFrm->Frm();
+ aRect = m_pFlyFrame->Frame();
if( aRect.IsInside( rRec.aPos ) )
{
@@ -989,7 +989,7 @@ SdrObject* SwVirtFlyDrawObj::CheckMacroHit( const SdrObjMacroHitRec& rRec ) cons
if( aRect.IsInside( rRec.aPos ) )
{
if( !rURL.GetMap() ||
- m_pFlyFrm->GetFormat()->GetIMapObject( rRec.aPos, m_pFlyFrm ))
+ m_pFlyFrame->GetFormat()->GetIMapObject( rRec.aPos, m_pFlyFrame ))
return const_cast<SdrObject*>(static_cast<SdrObject const *>(this));
return nullptr;
diff --git a/sw/source/core/draw/dpage.cxx b/sw/source/core/draw/dpage.cxx
index 31d69f70ae07..f8ad9f6253cf 100644
--- a/sw/source/core/draw/dpage.cxx
+++ b/sw/source/core/draw/dpage.cxx
@@ -116,12 +116,12 @@ SdrObject* SwDPage::ReplaceObject( SdrObject* pNewObj, size_t nObjNum )
return FmFormPage::ReplaceObject( pNewObj, nObjNum );
}
-void InsertGridFrame( SdrPageGridFrameList *pLst, const SwFrm *pPg )
+void InsertGridFrame( SdrPageGridFrameList *pLst, const SwFrame *pPg )
{
SwRect aPrt( pPg->Prt() );
- aPrt += pPg->Frm().Pos();
+ aPrt += pPg->Frame().Pos();
const Rectangle aUser( aPrt.SVRect() );
- const Rectangle aPaper( pPg->Frm().SVRect() );
+ const Rectangle aPaper( pPg->Frame().SVRect() );
pLst->Insert( SdrPageGridFrame( aPaper, aUser ) );
}
@@ -148,9 +148,9 @@ const SdrPageGridFrameList* SwDPage::GetGridFrameList(
{
//The drawing demands all pages which overlap with the rest.
const SwRect aRect( *pRect );
- const SwFrm *pPg = pSh->GetLayout()->Lower();
+ const SwFrame *pPg = pSh->GetLayout()->Lower();
do
- { if ( pPg->Frm().IsOver( aRect ) )
+ { if ( pPg->Frame().IsOver( aRect ) )
::InsertGridFrame( const_cast<SwDPage*>(this)->pGridLst, pPg );
pPg = pPg->GetNext();
} while ( pPg );
@@ -158,12 +158,12 @@ const SdrPageGridFrameList* SwDPage::GetGridFrameList(
else
{
//The drawing demands all visible pages
- const SwFrm *pPg = pSh->Imp()->GetFirstVisPage(pSh->GetOut());
+ const SwFrame *pPg = pSh->Imp()->GetFirstVisPage(pSh->GetOut());
if ( pPg )
do
{ ::InsertGridFrame( const_cast<SwDPage*>(this)->pGridLst, pPg );
pPg = pPg->GetNext();
- } while ( pPg && pPg->Frm().IsOver( pSh->VisArea() ) );
+ } while ( pPg && pPg->Frame().IsOver( pSh->VisArea() ) );
}
}
return pGridLst;
@@ -187,7 +187,7 @@ bool SwDPage::RequestHelp( vcl::Window* pWindow, SdrView* pView,
if( pView->PickObj( aPos, 0, pObj, pPV, SdrSearchOptions::PICKMACRO ) &&
dynamic_cast<const SwVirtFlyDrawObj*>( pObj) != nullptr )
{
- SwFlyFrm *pFly = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrm();
+ SwFlyFrame *pFly = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrame();
const SwFormatURL &rURL = pFly->GetFormat()->GetURL();
OUString sText;
if( rURL.GetMap() )
@@ -212,7 +212,7 @@ bool SwDPage::RequestHelp( vcl::Window* pWindow, SdrView* pView,
{
// then append the relative pixel position!!
Point aPt( aPos );
- aPt -= pFly->Frm().Pos();
+ aPt -= pFly->Frame().Pos();
// without MapMode-Offset !!!!!
// without MapMode-Offset, without Offset, w ... !!!!!
aPt = pWindow->LogicToPixel(
diff --git a/sw/source/core/draw/dview.cxx b/sw/source/core/draw/dview.cxx
index cdfc35a61873..ad6f7df0764e 100644
--- a/sw/source/core/draw/dview.cxx
+++ b/sw/source/core/draw/dview.cxx
@@ -74,20 +74,20 @@ bool SwSdrHdl::IsFocusHdl() const
return SdrHdl::IsFocusHdl();
}
-static const SwFrm *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
+static const SwFrame *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
{
const SwVirtFlyDrawObj *pVirt = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) != nullptr ?
static_cast<const SwVirtFlyDrawObj*>(pObj) : nullptr;
if ( pVirt )
{
- if ( bAll || !pVirt->GetFlyFrm()->IsFlyInCntFrm() )
- return pVirt->GetFlyFrm()->GetAnchorFrm();
+ if ( bAll || !pVirt->GetFlyFrame()->IsFlyInContentFrame() )
+ return pVirt->GetFlyFrame()->GetAnchorFrame();
}
else
{
const SwDrawContact *pCont = static_cast<const SwDrawContact*>(GetUserCall(pObj));
if ( pCont )
- return pCont->GetAnchorFrm( pObj );
+ return pCont->GetAnchorFrame( pObj );
}
return nullptr;
}
@@ -145,9 +145,9 @@ SdrObject* impLocalHitCorrection(SdrObject* pRetval, const Point& rPnt, sal_uInt
if(pSwVirtFlyDrawObj)
{
- if(pSwVirtFlyDrawObj->GetFlyFrm()->Lower() && pSwVirtFlyDrawObj->GetFlyFrm()->Lower()->IsNoTextFrm())
+ if(pSwVirtFlyDrawObj->GetFlyFrame()->Lower() && pSwVirtFlyDrawObj->GetFlyFrame()->Lower()->IsNoTextFrame())
{
// the old method used IsNoTextFrm (should be for SW's own OLE and
// graphic's) to accept hit only based on outer bounds; nothing to do
}
else
@@ -220,7 +220,7 @@ void SwDrawView::AddCustomHdl()
if (FLY_AS_CHAR == rAnchor.GetAnchorId())
return;
- const SwFrm* pAnch;
+ const SwFrame* pAnch;
if(nullptr == (pAnch = CalcAnchor()))
return;
@@ -247,14 +247,14 @@ SdrObject* SwDrawView::GetMaxToTopObj( SdrObject* pObj ) const
{
if ( GetUserCall(pObj) )
{
- const SwFrm *pAnch = ::lcl_FindAnchor( pObj, false );
+ const SwFrame *pAnch = ::lcl_FindAnchor( pObj, false );
if ( pAnch )
{
//The topmost Obj within the anchor must not be overtaken.
- const SwFlyFrm *pFly = pAnch->FindFlyFrm();
+ const SwFlyFrame *pFly = pAnch->FindFlyFrame();
if ( pFly )
{
- const SwPageFrm *pPage = pFly->FindPageFrm();
+ const SwPageFrame *pPage = pFly->FindPageFrame();
if ( pPage->GetSortedObjs() )
{
size_t nOrdNum = 0;
@@ -264,7 +264,7 @@ SdrObject* SwDrawView::GetMaxToTopObj( SdrObject* pObj ) const
if ( pO->GetOrdNumDirect() > nOrdNum )
{
- const SwFrm *pTmpAnch = ::lcl_FindAnchor( pO, false );
+ const SwFrame *pTmpAnch = ::lcl_FindAnchor( pO, false );
if ( pFly->IsAnLower( pTmpAnch ) )
{
nOrdNum = pO->GetOrdNumDirect();
@@ -291,11 +291,11 @@ SdrObject* SwDrawView::GetMaxToBtmObj(SdrObject* pObj) const
{
if ( GetUserCall(pObj) )
{
- const SwFrm *pAnch = ::lcl_FindAnchor( pObj, false );
+ const SwFrame *pAnch = ::lcl_FindAnchor( pObj, false );
if ( pAnch )
{
//The Fly of the anchor must not be "flying under".
- const SwFlyFrm *pFly = pAnch->FindFlyFrm();
+ const SwFlyFrame *pFly = pAnch->FindFlyFrame();
if ( pFly )
{
SdrObject *pRet = const_cast<SdrObject*>(static_cast<SdrObject const *>(pFly->GetVirtDrawObj()));
@@ -307,7 +307,7 @@ SdrObject* SwDrawView::GetMaxToBtmObj(SdrObject* pObj) const
}
/// determine maximal order number for a 'child' object of given 'parent' object
-sal_uInt32 SwDrawView::_GetMaxChildOrdNum( const SwFlyFrm& _rParentObj,
+sal_uInt32 SwDrawView::_GetMaxChildOrdNum( const SwFlyFrame& _rParentObj,
const SdrObject* _pExclChildObj )
{
sal_uInt32 nMaxChildOrdNum = _rParentObj.GetDrawObj()->GetOrdNum();
@@ -366,11 +366,11 @@ void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
nNewPos );
pDrawPage->RecalcObjOrdNums();
// adjustments for accessibility API
- if ( dynamic_cast< const SwFlyFrm *>( pAnchoredObj ) != nullptr )
+ if ( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) != nullptr )
{
- const SwFlyFrm *pTmpFlyFrm = static_cast<SwFlyFrm*>(pAnchoredObj);
- rImp.DisposeAccessibleFrm( pTmpFlyFrm );
- rImp.AddAccessibleFrm( pTmpFlyFrm );
+ const SwFlyFrame *pTmpFlyFrame = static_cast<SwFlyFrame*>(pAnchoredObj);
+ rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+ rImp.AddAccessibleFrame( pTmpFlyFrame );
}
else
{
@@ -402,11 +402,11 @@ void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
nTmpNewPos );
pDrawPage->RecalcObjOrdNums();
// adjustments for accessibility API
- if ( dynamic_cast< const SwFlyFrm *>( pAnchoredObj ) != nullptr )
+ if ( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) != nullptr )
{
- const SwFlyFrm *pTmpFlyFrm = static_cast<SwFlyFrm*>(pAnchoredObj);
- rImp.DisposeAccessibleFrm( pTmpFlyFrm );
- rImp.AddAccessibleFrm( pTmpFlyFrm );
+ const SwFlyFrame *pTmpFlyFrame = static_cast<SwFlyFrame*>(pAnchoredObj);
+ rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+ rImp.AddAccessibleFrame( pTmpFlyFrame );
}
else
{
@@ -438,8 +438,8 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
SwAnchoredObject* pMovedAnchoredObj =
::GetUserCall( pObj )->GetAnchoredObj( pObj );
- const SwFlyFrm* pParentAnchoredObj =
- pMovedAnchoredObj->GetAnchorFrm()->FindFlyFrm();
+ const SwFlyFrame* pParentAnchoredObj =
+ pMovedAnchoredObj->GetAnchorFrame()->FindFlyFrame();
const bool bMovedForward = nOldPos < nNewPos;
@@ -507,11 +507,11 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
// On move forward, assure that object is moved before its own children.
// Only Writer fly frames can have children.
- if ( dynamic_cast< const SwFlyFrm *>( pMovedAnchoredObj ) != nullptr &&
+ if ( dynamic_cast< const SwFlyFrame *>( pMovedAnchoredObj ) != nullptr &&
bMovedForward && nNewPos < nObjCount - 1 )
{
sal_uInt32 nMaxChildOrdNum =
- _GetMaxChildOrdNum( *(static_cast<const SwFlyFrm*>(pMovedAnchoredObj)) );
+ _GetMaxChildOrdNum( *(static_cast<const SwFlyFrame*>(pMovedAnchoredObj)) );
if ( nNewPos < nMaxChildOrdNum )
{
// determine position before the object before its top 'child' object
@@ -545,9 +545,9 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
// If object is anchored inside a invisible part of the document
// (e.g. page header, whose page style isn't applied, or hidden
// section), no anchor frame exists.
- const SwFrm* pTmpAnchorFrm = lcl_FindAnchor( pTmpObj, true );
- const SwFlyFrm* pTmpParentObj = pTmpAnchorFrm
- ? pTmpAnchorFrm->FindFlyFrm() : nullptr;
+ const SwFrame* pTmpAnchorFrame = lcl_FindAnchor( pTmpObj, true );
+ const SwFlyFrame* pTmpParentObj = pTmpAnchorFrame
+ ? pTmpAnchorFrame->FindFlyFrame() : nullptr;
if ( pTmpParentObj &&
&(pTmpParentObj->GetFrameFormat()) != pParentFrameFormat )
{
@@ -578,13 +578,13 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
std::vector< SdrObject* > aMovedChildObjs;
// move 'children' accordingly
- if ( dynamic_cast< const SwFlyFrm *>( pMovedAnchoredObj ) != nullptr )
+ if ( dynamic_cast< const SwFlyFrame *>( pMovedAnchoredObj ) != nullptr )
{
- const SwFlyFrm* pFlyFrm = static_cast<SwFlyFrm*>(pMovedAnchoredObj);
+ const SwFlyFrame* pFlyFrame = static_cast<SwFlyFrame*>(pMovedAnchoredObj);
// adjustments for accessibility API
- rImp.DisposeAccessibleFrm( pFlyFrm );
- rImp.AddAccessibleFrm( pFlyFrm );
+ rImp.DisposeAccessibleFrame( pFlyFrame );
+ rImp.AddAccessibleFrame( pFlyFrame );
const sal_uInt32 nChildNewPos = bMovedForward ? nNewPos : nNewPos+1;
size_t i = bMovedForward ? nOldPos : nObjCount-1;
@@ -598,12 +598,12 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
// If object is anchored inside a invisible part of the document
// (e.g. page header, whose page style isn't applied, or hidden
// section), no anchor frame exists.
- const SwFrm* pTmpAnchorFrm = lcl_FindAnchor( pTmpObj, true );
- const SwFlyFrm* pTmpParentObj = pTmpAnchorFrm
- ? pTmpAnchorFrm->FindFlyFrm() : nullptr;
+ const SwFrame* pTmpAnchorFrame = lcl_FindAnchor( pTmpObj, true );
+ const SwFlyFrame* pTmpParentObj = pTmpAnchorFrame
+ ? pTmpAnchorFrame->FindFlyFrame() : nullptr;
if ( pTmpParentObj &&
- ( ( pTmpParentObj == pFlyFrm ) ||
- ( pFlyFrm->IsUpperOf( *pTmpParentObj ) ) ) )
+ ( ( pTmpParentObj == pFlyFrame ) ||
+ ( pFlyFrame->IsUpperOf( *pTmpParentObj ) ) ) )
{
// move child object.,
pDrawPage->SetObjectOrdNum( i, nChildNewPos );
@@ -613,10 +613,10 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
// adjustments for accessibility API
if ( dynamic_cast< const SwVirtFlyDrawObj *>( pTmpObj ) != nullptr )
{
- const SwFlyFrm *pTmpFlyFrm =
- static_cast<SwVirtFlyDrawObj*>(pTmpObj)->GetFlyFrm();
- rImp.DisposeAccessibleFrm( pTmpFlyFrm );
- rImp.AddAccessibleFrm( pTmpFlyFrm );
+ const SwFlyFrame *pTmpFlyFrame =
+ static_cast<SwVirtFlyDrawObj*>(pTmpObj)->GetFlyFrame();
+ rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+ rImp.AddAccessibleFrame( pTmpFlyFrame );
}
else
{
@@ -664,7 +664,7 @@ bool SwDrawView::TakeDragLimit( SdrDragMode eMode,
return bRet;
}
-const SwFrm* SwDrawView::CalcAnchor()
+const SwFrame* SwDrawView::CalcAnchor()
{
const SdrMarkList &rMrkList = GetMarkedObjectList();
if ( rMrkList.GetMarkCount() != 1 )
@@ -674,26 +674,26 @@ const SwFrm* SwDrawView::CalcAnchor()
//Search for paragraph bound objects, otherwise only the
//current anchor. Search only if we currently drag.
- const SwFrm* pAnch;
+ const SwFrame* pAnch;
Rectangle aMyRect;
const bool bFly = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) != nullptr;
if ( bFly )
{
- pAnch = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrm()->GetAnchorFrm();
- aMyRect = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrm()->Frm().SVRect();
+ pAnch = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrame()->GetAnchorFrame();
+ aMyRect = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrame()->Frame().SVRect();
}
else
{
SwDrawContact *pC = static_cast<SwDrawContact*>(GetUserCall(pObj));
// determine correct anchor position for 'virtual' drawing objects.
// #i26791#
- pAnch = pC->GetAnchorFrm( pObj );
+ pAnch = pC->GetAnchorFrame( pObj );
if( !pAnch )
{
pC->ConnectToLayout();
// determine correct anchor position for 'virtual' drawing objects.
// #i26791#
- pAnch = pC->GetAnchorFrm( pObj );
+ pAnch = pC->GetAnchorFrame( pObj );
}
aMyRect = pObj->GetSnapRect();
}
@@ -717,27 +717,27 @@ const SwFrm* SwDrawView::CalcAnchor()
if ( aPt != aMyPt )
{
- if ( pAnch && pAnch->IsContentFrm() )
+ if ( pAnch && pAnch->IsContentFrame() )
{
// allow drawing objects in header/footer,
// but exclude control objects.
bool bBodyOnly = CheckControlLayer( pObj );
- pAnch = ::FindAnchor( static_cast<const SwContentFrm*>(pAnch), aPt, bBodyOnly );
+ pAnch = ::FindAnchor( static_cast<const SwContentFrame*>(pAnch), aPt, bBodyOnly );
}
else if ( !bFly )
{
const SwRect aRect( aPt.getX(), aPt.getY(), 1, 1 );
SwDrawContact* pContact = static_cast<SwDrawContact*>(GetUserCall(pObj));
- if ( pContact->GetAnchorFrm( pObj ) &&
- pContact->GetAnchorFrm( pObj )->IsPageFrm() )
- pAnch = pContact->GetPageFrm();
+ if ( pContact->GetAnchorFrame( pObj ) &&
+ pContact->GetAnchorFrame( pObj )->IsPageFrame() )
+ pAnch = pContact->GetPageFrame();
else
pAnch = pContact->FindPage( aRect );
}
}
if( pAnch && !pAnch->IsProtected() )
- aAnchorPoint = pAnch->GetFrmAnchorPos( ::HasWrap( pObj ) );
+ aAnchorPoint = pAnch->GetFrameAnchorPos( ::HasWrap( pObj ) );
else
pAnch = nullptr;
return pAnch;
@@ -818,16 +818,16 @@ void SwDrawView::CheckPossibilities()
for ( size_t i = 0; !bProtect && i < rMrkList.GetMarkCount(); ++i )
{
const SdrObject *pObj = rMrkList.GetMark( i )->GetMarkedSdrObj();
- const SwFrm *pFrm = nullptr;
+ const SwFrame *pFrame = nullptr;
if ( dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) != nullptr )
{
- const SwFlyFrm *pFly = static_cast<const SwVirtFlyDrawObj*>(pObj)->GetFlyFrm();
+ const SwFlyFrame *pFly = static_cast<const SwVirtFlyDrawObj*>(pObj)->GetFlyFrame();
if ( pFly )
{
- pFrm = pFly->GetAnchorFrm();
- if ( pFly->Lower() && pFly->Lower()->IsNoTextFrm() )
+ pFrame = pFly->GetAnchorFrame();
+ if ( pFly->Lower() && pFly->Lower()->IsNoTextFrame() )
{
- SwOLENode *pNd = const_cast<SwContentFrm*>(static_cast<const SwContentFrm*>(pFly->Lower()))->GetNode()->GetOLENode();
+ SwOLENode *pNd = const_cast<SwContentFrame*>(static_cast<const SwContentFrame*>(pFly->Lower()))->GetNode()->GetOLENode();
if ( pNd )
{
uno::Reference < embed::XEmbeddedObject > xObj = pNd->GetOLEObj().GetOleRef();
@@ -855,10 +855,10 @@ void SwDrawView::CheckPossibilities()
{
SwDrawContact *pC = static_cast<SwDrawContact*>(GetUserCall(pObj));
if ( pC )
- pFrm = pC->GetAnchorFrm( pObj );
+ pFrame = pC->GetAnchorFrame( pObj );
}
- if ( pFrm )
- bProtect = pFrm->IsProtected(); //Frames, areas etc.
+ if ( pFrame )
+ bProtect = pFrame->IsProtected(); //Frames, areas etc.
{
SwFrameFormat* pFrameFormat( ::FindFrameFormat( const_cast<SdrObject*>(pObj) ) );
if ( !pFrameFormat )
@@ -922,7 +922,7 @@ void SwDrawView::ReplaceMarkedDrawVirtObjs( SdrMarkView& _rMarkView )
void SwDrawView::DeleteMarked()
{
SwDoc* pDoc = Imp().GetShell()->GetDoc();
- SwRootFrm *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
+ SwRootFrame *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
if ( pTmpRoot )
pTmpRoot->StartAllAction();
pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, nullptr);
@@ -145,9 +145,9 @@ SdrObject* impLocalHitCorrection(SdrObject* pRetval, const Point& rPnt, sal_uInt
{
- // the old method used IsNoTextFrm (should be for SW's own OLE and
+ // the old method used IsNoTextFrame (should be for SW's own OLE and
// graphic's) to accept hit only based on outer bounds; nothing to do
}